![pypi](https://img.shields.io/pypi/v/git-message-hook.svg)
![python](https://img.shields.io/pypi/pyversions/git-message-hook.svg)
![license](https://img.shields.io/github/license/oscar-defelice/git-message-hook.svg)
![last-commit](https://img.shields.io/github/last-commit/oscar-defelice/git-message-hook.svg)
![docs](https://readthedocs.org/projects/git-message-hook/badge/?version=latest)
[![patreon](https://img.shields.io/badge/Patreon-brown.svg?logo=patreon)](https://www.patreon.com/oscardefelice)
[![follow](https://img.shields.io/twitter/follow/oscardefelice.svg?style=social)](https://twitter.com/OscardeFelice)
[![linkedin](https://img.shields.io/badge/LinkedIn-0077B5?&logo=linkedin&logoColor=white)](https://linkedin.com/in/oscar-de-felice)

# git-message-hook

![project logo](https://raw.githubusercontent.com/oscar-defelice/git-message-hook/main/logo.png)

Enforces [conventional git commit messages](https://www.conventionalcommits.org/en/v1.0.0-beta.4/) for all new git repositories you create by running `git init`

# Installation

```bash
pip install git-message-hook
```

# Documentation

Detailed docs are available at <https://git-message-hook.readthedocs.io/en/latest/>.

# Attribution

<div>Icons made by <a href="https://www.flaticon.com/authors/smashicons" title="Smashicons">Smashicons</a> from <a href="https://www.flaticon.com/" 		    title="Flaticon">www.flaticon.com</a> is licensed by <a href="http://creativecommons.org/licenses/by/3.0/" 		    title="Creative Commons BY 3.0" target="_blank">CC 3.0 BY</a></div>
